from django.db.backends.mysql import schema as myschema


class DatabaseSchemaEditor(myschema.DatabaseSchemaEditor):
    sql_delete_table = "DROP TABLE %(table)s"
    sql_delete_column = "ALTER TABLE %(table)s DROP COLUMN %(column)s"

    def remove_field(self, model, field):
        # Drop any Index, TiDB requires explicite deletion
        if field.db_index:
            idx_names = self._constraint_names(model, [field.column], index=True)
            for idx_name in idx_names:
                self.execute(self._delete_constraint_sql(self.sql_delete_index, model, idx_name))
        super(DatabaseSchemaEditor, self).remove_field(model, field)



"""
TiDB database backend for Django. Based on django's MySQL backend

Requires mysqlclient: https://pypi.python.org/pypi/mysqlclient/
MySQLdb is supported for Python 2 only: http://sourceforge.net/projects/mysql-python
"""

from django.db.backends.mysql import base as mybase

# Some of these import MySQLdb, so import them after checking if it's installed.
from .features import DatabaseFeatures                      # isort:skip
from .schema import DatabaseSchemaEditor                    # isort:skip


class DatabaseWrapper(mybase.DatabaseWrapper):
    SchemaEditorClass = DatabaseSchemaEditor

    def __init__(self, *args, **kwargs):
        super(DatabaseWrapper, self).__init__(*args, **kwargs)
        self.features = DatabaseFeatures(self)



#!/usr/bin/env python

from distutils.core import setup

long_description = """TiDB backend for Django"""

setup(
    name='django_tidb',
    version='2.1.1',
    author='Rain Li',
    author_email='blacktear23@gmail.com',
    url='http://github.com/blacktear23/django_tidb',
    download_url='http://github.com/blackear23/django_tidb/archive/2.1.tar.gz',
    description='TiDB backend for Django',
    long_description=long_description,
    keywords=['django', 'tidb'],
    packages=['django_tidb', 'django_tidb.tidb'],
    license='Apache2',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: Implementation :: CPython',
        'Topic :: Software Development :: Libraries',
    ],
)
